==> freecad_0.17%2Bdfsg1.orig.tar.gz: FreeCAD-0.17/src/Mod/Web/Gui/Resources/translations/Web_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nl" sourcelanguage="en">
  <context>
    <name>CmdWebBrowserBack</name>
    <message>
      <location filename="../../Command.cpp" line="76"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="77"/>
      <source>Previous page</source>
      <translation>Vorige pagina</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="78"/>
      <source>Go back to the previous page</source>
      <translation>Teruggaan naar de vorige pagina</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserNext</name>
    <message>
      <location filename="../../Command.cpp" line="105"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="106"/>
      <source>Next page</source>
      <translation>Volgende pagina</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="107"/>
      <source>Go to the next page</source>
      <translation>Naar de volgende pagina gaan</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserRefresh</name>
    <message>
      <location filename="../../Command.cpp" line="134"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="135"/>
      <location filename="../../Command.cpp" line="136"/>
      <source>Refresh web page</source>
      <translation>Webpagina vernieuwen</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserStop</name>
    <message>
      <location filename="../../Command.cpp" line="162"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="163"/>
      <source>Stop loading</source>
      <translation>Stoppen met laden</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="164"/>
      <source>Stop the current loading</source>
      <translation>Het huidige laden stoppen</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserZoomIn</name>
    <message>
      <location filename="../../Command.cpp" line="192"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="193"/>
      <source>Zoom in</source>
      <translation>Inzoomen</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="194"/>
      <source>Zoom into the page</source>
      <translation>Inzoomen op de pagina</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserZoomOut</name>
    <message>
      <location filename="../../Command.cpp" line="221"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="222"/>
      <source>Zoom out</source>
      <translation>Uitzoomen</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="223"/>
      <source>Zoom out of the page</source>
      <translation>Uitzoomen van de pagina</translation>
    </message>
  </context>
  <context>
    <name>CmdWebOpenWebsite</name>
    <message>
      <location filename="../../Command.cpp" line="50"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="51"/>
      <source>Open website...</source>
      <translation>Website openen...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="52"/>
      <source>Opens a website in FreeCAD</source>
      <translation>Opent een website in FreeCAD</translation>
    </message>
  </context>
  <context>
    <name>Form</name>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="14"/>
      <source>Sketchfab exporter</source>
      <translation>Sketchfab exporteur</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="39"/>
      <source>What to upload?</source>
      <translation>Hoe om te uploaden?</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="46"/>
      <source>Selection</source>
      <translation>Selectie</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="56"/>
      <source>All visible objects</source>
      <translation>Alle zichtbare objecten</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="81"/>
      <source>Model name</source>
      <translation>Modelnaam</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="88"/>
      <source>Private</source>
      <translation>Persoonlijk</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="100"/>
      <source>Description</source>
      <translation>Omschrijving</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="110"/>
      <source>Tags (separated by commas)</source>
      <translation>Tags (gescheiden door komma's)</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="119"/>
      <source>FreeCAD,</source>
      <translation>FreeCAD,</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="135"/>
      <source>Format</source>
      <translation>Formaat</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="143"/>
      <source>OBJ + MTL (Arch exporter)</source>
      <translation>OBJ + MTL (Arch exporteur)</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="148"/>
      <source>OBJ (standard Mesh exporter)</source>
      <translation>OBJ (standaard Mesh exporteur)</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="153"/>
      <source>DAE (Collada)</source>
      <translation>DAE (Collada)</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="158"/>
      <source>STL</source>
      <translation>STL</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="163"/>
      <source>IGES (shapes only)</source>
      <translation>IGES (alleen vormen)</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="168"/>
      <source>IV</source>
      <translation>IV</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="176"/>
      <source>Sketchfab API token</source>
      <translation>Sketchfab API token</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="192"/>
      <source>Obtain</source>
      <translation>Verkrijgen</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="201"/>
      <source>Upload</source>
      <translation type="unfinished">Upload</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="211"/>
      <source>uploading</source>
      <translation>uploaden</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="218"/>
      <source>Success! View uploaded online</source>
      <translation>Succes! Bekijk online je upload</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../AppWebGui.cpp" line="80"/>
      <location filename="../../BrowserView.cpp" line="412"/>
      <source>Browser</source>
      <translation>Browser</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="309"/>
      <source>File does not exist!</source>
      <translation>Bestand bestaat niet!</translation>
    </message>
  </context>
  <context>
    <name>WebGui::BrowserView</name>
    <message>
      <location filename="../../BrowserView.cpp" line="304"/>
      <source>Error</source>
      <translation>Fout</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="383"/>
      <source>Loading %1...</source>
      <translation>Laden %1...</translation>
    </message>
  </context>
  <context>
    <name>WebGui::WebView</name>
    <message>
      <location filename="../../BrowserView.cpp" line="181"/>
      <source>Open in External Browser</source>
      <translation>Open in externe Browser</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="185"/>
      <source>Open in new window</source>
      <translation>In nieuw venster openen</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="46"/>
      <source>Navigation</source>
      <translation>Navigatie</translation>
    </message>
  </context>
</TS>

==> freecad_0.18~pre1%2Bdfsg1.orig.tar.gz: FreeCAD-0.18_pre/src/Mod/Web/Gui/Resources/translations/Web_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nl" sourcelanguage="en">
  <context>
    <name>CmdWebBrowserBack</name>
    <message>
      <location filename="../../Command.cpp" line="76"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="77"/>
      <source>Previous page</source>
      <translation>Vorige pagina</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="78"/>
      <source>Go back to the previous page</source>
      <translation>Teruggaan naar de vorige pagina</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserNext</name>
    <message>
      <location filename="../../Command.cpp" line="105"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="106"/>
      <source>Next page</source>
      <translation>Volgende pagina</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="107"/>
      <source>Go to the next page</source>
      <translation>Naar de volgende pagina gaan</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserRefresh</name>
    <message>
      <location filename="../../Command.cpp" line="134"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="135"/>
      <location filename="../../Command.cpp" line="136"/>
      <source>Refresh web page</source>
      <translation>Webpagina vernieuwen</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserStop</name>
    <message>
      <location filename="../../Command.cpp" line="162"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="163"/>
      <source>Stop loading</source>
      <translation>Stoppen met laden</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="164"/>
      <source>Stop the current loading</source>
      <translation>Het huidige laden stoppen</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserZoomIn</name>
    <message>
      <location filename="../../Command.cpp" line="192"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="193"/>
      <source>Zoom in</source>
      <translation>Inzoomen</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="194"/>
      <source>Zoom into the page</source>
      <translation>Inzoomen op de pagina</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserZoomOut</name>
    <message>
      <location filename="../../Command.cpp" line="221"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="222"/>
      <source>Zoom out</source>
      <translation>Uitzoomen</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="223"/>
      <source>Zoom out of the page</source>
      <translation>Uitzoomen van de pagina</translation>
    </message>
  </context>
  <context>
    <name>CmdWebOpenWebsite</name>
    <message>
      <location filename="../../Command.cpp" line="50"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="51"/>
      <source>Open website...</source>
      <translation>Website openen...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="52"/>
      <source>Opens a website in FreeCAD</source>
      <translation>Opent een website in FreeCAD</translation>
    </message>
  </context>
  <context>
    <name>Form</name>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="14"/>
      <source>Sketchfab exporter</source>
      <translation>Sketchfab exporteur</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="39"/>
      <source>What to upload?</source>
      <translation>Wat te uploaden?</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="46"/>
      <source>Selection</source>
      <translation>Selectie</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="56"/>
      <source>All visible objects</source>
      <translation>Alle zichtbare objecten</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="81"/>
      <source>Model name</source>
      <translation>Modelnaam</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="88"/>
      <source>Private</source>
      <translation>Privé</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="100"/>
      <source>Description</source>
      <translation>Omschrijving</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="110"/>
      <source>Tags (separated by commas)</source>
      <translation>Tags (gescheiden door komma's)</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="119"/>
      <source>FreeCAD,</source>
      <translation>FreeCAD,</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="135"/>
      <source>Format</source>
      <translation>Formaat</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="143"/>
      <source>OBJ + MTL (Arch exporter)</source>
      <translation>OBJ + MTL (Arch exporteur)</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="148"/>
      <source>OBJ (standard Mesh exporter)</source>
      <translation>OBJ (standaard Mesh exporteur)</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="153"/>
      <source>DAE (Collada)</source>
      <translation>DAE (Collada)</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="158"/>
      <source>STL</source>
      <translation>STL</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="163"/>
      <source>IGES (shapes only)</source>
      <translation>IGES (alleen vormen)</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="168"/>
      <source>IV</source>
      <translation>IV</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="176"/>
      <source>Sketchfab API token</source>
      <translation>Sketchfab API token</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="192"/>
      <source>Obtain</source>
      <translation>Verkrijgen</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="201"/>
      <source>Upload</source>
      <translation>Verzenden</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="211"/>
      <source>uploading</source>
      <translation>uploaden</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="218"/>
      <source>Success! View uploaded online</source>
      <translation>Succes! Bekijk online je upload</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../AppWebGui.cpp" line="80"/>
      <location filename="../../BrowserView.cpp" line="440"/>
      <source>Browser</source>
      <translation>Browser</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="337"/>
      <source>File does not exist!</source>
      <translation>Bestand bestaat niet!</translation>
    </message>
  </context>
  <context>
    <name>WebGui::BrowserView</name>
    <message>
      <location filename="../../BrowserView.cpp" line="329"/>
      <location filename="../../BrowserView.cpp" line="333"/>
      <source>Error</source>
      <translation>Fout</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="333"/>
      <source>There were errors while loading the file. Some data might have been modified or not recovered at all. Look in the report view for more specific information about the objects involved.</source>
      <translation>Er zijn fouten opgetreden tijdens het laden van het bestand. Sommige gegevens zijn misschien gewijzigd of helemaal hersteld. Kijk in de rapportweergave voor meer specifieke informatie over de objecten die hierbij zijn betrokken.</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="411"/>
      <source>Loading %1...</source>
      <translation>Laden %1...</translation>
    </message>
  </context>
  <context>
    <name>WebGui::WebView</name>
    <message>
      <location filename="../../BrowserView.cpp" line="185"/>
      <source>Open in External Browser</source>
      <translation>Open in externe Browser</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="189"/>
      <source>Open in new window</source>
      <translation>In nieuw venster openen</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="46"/>
      <source>Navigation</source>
      <translation>Navigatie</translation>
    </message>
  </context>
</TS>
